@@ -9,13 +9,13 @@ using namespace std::chrono;
 using ROCKSDB_NAMESPACE::DB;
 using ROCKSDB_NAMESPACE::ReadOptions;
 using ROCKSDB_NAMESPACE::Status;
+using ROCKSDB_NAMESPACE::WriteBatch;
 using ROCKSDB_NAMESPACE::WriteOptions;
 
-const char *PREFIX = "test_";
+const char *PREFIX = "test";
 
 // Measure running time of the given function
-template <typename Function>
-int timeit(Function f, int size, DB *db)
+int timeit(function<void(DB *, int)> const &f, int size, DB *db)
 {
     time_point<high_resolution_clock> start_time, end_time;
 
@@ -29,16 +29,13 @@ int timeit(Function f, int size, DB *db)
     end_time = high_resolution_clock::now();
 
     // Get start time diff from epoch
-    auto start = time_point_cast<microseconds>(start_time).time_since_epoch().count();
+    auto diff = duration_cast<microseconds>(end_time - start_time).count();
 
-    // Get end time diff from epoch
-    auto end = time_point_cast<microseconds>(end_time).time_since_epoch().count();
-
-    return end - start;
+    return diff;
 }
 
 // Get value by given key
-string get_key(DB *db, string key)
+string get(DB *db, string key)
 {
     string value;
     Status status;
@@ -55,7 +52,7 @@ string get_key(DB *db, string key)
 }
 
 // Set entry for given key and value
-void put_key(DB *db, string key, string value)
+void put(DB *db, string key, string value)
 {
     Status status;
 
@@ -64,3 +61,19 @@ void put_key(DB *db, string key, string value)
 
     assert(status.ok());
 }
+
+// Set multiple entries for given group of keys and values
+void put_multi(DB *db, string **keys, string **values, int *len)
+{
+    Status status;
+    WriteBatch b;
+
+    for (int i = 0; i < *len; i++)
+    {
+        b.Put((*keys)[i], (*values)[i]);
+    }
+
+    status = db->Write(WriteOptions(), &b);
+
+    assert(status.ok());
+}
\ No newline at end of file
