@@ -11,7 +11,7 @@ class TestBasic(unittest.TestCase):
         self.db = rocksdbpy.open_default(self.temp)
 
     def tearDown(self):
-        del self.db
+        self.db.close()
 
         shutil.rmtree(self.temp)
 
